//  Diffusion Client Library for iOS, tvOS and OS X / macOS
//
//  Copyright (c) 2015, 2017 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;
#import <Diffusion/PTDiffusionStreamDelegate.h>
#import <Diffusion/PTDiffusionTopicUnsubscriptionReason.h>

@class PTDiffusionContent;
@class PTDiffusionStream;
@class PTDiffusionTopicDetails;
@class PTDiffusionUpdateContext;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief The topic stream delegate protocol defines the methods to be implemented by classes
 wishing to receive streamed topic updates.

 @see PTDiffusionTopicsFeature
 
 @deprecated Since 6.0. Topic streams are only necessary to support the
 deprecated stateless and record topic types. They will be removed along with
 these topic types in a future release.

 @since 5.6
 */
__deprecated_msg("Will be removed in a future release.")
@protocol PTDiffusionTopicStreamDelegate <PTDiffusionStreamDelegate>

/**
 An update was received for a topic path handled by the topic stream.

 @param stream The topic stream that received the update.

 @param topicPath The topic path that was updated.

 @param content The content of the updated topic.

 @param context The context of the update.

 @since 5.6
 */
-(void)diffusionStream:(PTDiffusionStream *)stream
    didUpdateTopicPath:(NSString *)topicPath
               content:(PTDiffusionContent *)content
               context:(PTDiffusionUpdateContext *)context;

/**
 A subscription notification was received for a topic path handled by the topic stream.

 The subscription could be as a result of a request from this client's associated session or it
 might have been requested by another control client.

 @param stream The topic stream that received the subscription notification.

 @param topicPath The topic path to which the session has been subscribed.

 @param details The details of the subscription.

 @since 5.6
 */
-(void)     diffusionStream:(PTDiffusionStream *)stream
    didSubscribeToTopicPath:(NSString *)topicPath
                    details:(PTDiffusionTopicDetails *)details;

/**
 An unsubscription notification was received for a topic path handled by the topic stream.

 The unsubscription could be as a result of a request from this client's associated session or it
 might have been requested by another control client.

 @param stream The topic stream that received the unsubscription notification.

 @param topicPath The topic path from which the session has been unsubscribed.

 @param reason The reason for the unsubscription.

 @since 5.7
 */
-(void)         diffusionStream:(PTDiffusionStream *)stream
    didUnsubscribeFromTopicPath:(NSString *)topicPath
                         reason:(PTDiffusionTopicUnsubscriptionReason)reason;

@end

NS_ASSUME_NONNULL_END
